@@ -26,7 +26,6 @@
 #include <unistd.h>
 
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-icon-theme.h>
 #include <libgnomeui/gnome-icon-lookup.h>
 #include <glade/glade.h>
 #include <libgnomevfs/gnome-vfs-types.h>
@@ -45,7 +44,7 @@
 #include "main.h"
 
 
-#define GLADE_FILE "file-roller.glade"
+#define GLADE_FILE "batch-add-files.glade"
 #define ARCHIVE_ICON_SIZE (48)
 #define DEFAULT_EXTENSION ".tar.gz"
 #define BAD_CHARS "/\\*"
@@ -116,11 +115,11 @@ add_clicked_cb (GtkWidget  *widget,
 
 	/* Collect data */
 
-	archive_name = g_filename_from_utf8 (gtk_entry_get_text (GTK_ENTRY (data->a_add_to_entry)), -1, NULL, NULL, NULL);
+	archive_name = gnome_vfs_escape_string (gtk_entry_get_text (GTK_ENTRY (data->a_add_to_entry)));
 
 	/* Check whether the user entered a valid archive name. */
 
-	if (*archive_name == '\0') {
+	if ((archive_name == NULL) || (*archive_name == '\0')) {
 		GtkWidget *d;
 
 		d = _gtk_error_dialog_new (GTK_WINDOW (window),
@@ -158,7 +157,12 @@ add_clicked_cb (GtkWidget  *widget,
 	/* Check directory existence. */
 
 	archive_dir = gtk_file_chooser_get_current_folder_uri (GTK_FILE_CHOOSER (data->a_location_filechooserbutton));
-
+	if (archive_dir == NULL) {
+		g_free (archive_dir);
+		g_free (archive_name);
+		return;
+	}
+		
 	if (! check_permissions (archive_dir, R_OK|W_OK|X_OK)) {
 		GtkWidget  *d;
 
@@ -243,8 +247,7 @@ add_clicked_cb (GtkWidget  *widget,
 	/**/
 
 	archive_ext = get_ext (data);
-	tmp = gnome_vfs_escape_string (archive_name);
-	g_free (archive_name);
+	tmp = archive_name;
 	archive_name = g_strconcat (tmp, archive_ext, NULL);
 	g_free (tmp);
 	archive_file = g_strconcat (archive_dir, "/", archive_name, NULL);
@@ -308,78 +311,19 @@ add_clicked_cb (GtkWidget  *widget,
 }
 
 
-/* taken from egg-recent-util.c */
-static GdkPixbuf *
-scale_icon (GdkPixbuf *pixbuf,
-	    double    *scale)
-{
-	guint width, height;
-
-	width = gdk_pixbuf_get_width (pixbuf);
-	height = gdk_pixbuf_get_height (pixbuf);
-
-	width = floor (width * *scale + 0.5);
-	height = floor (height * *scale + 0.5);
-
-	return gdk_pixbuf_scale_simple (pixbuf, width, height, GDK_INTERP_BILINEAR);
-}
-
-
-/* taken from egg-recent-util.c */
-static GdkPixbuf *
-load_icon_file (char          *filename,
-		guint          base_size,
-		guint          nominal_size)
-{
-	GdkPixbuf *pixbuf, *scaled_pixbuf;
-	guint      width, height, size;
-	double     scale;
-
-	pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-
-	if (pixbuf == NULL) {
-		return NULL;
-	}
-
-	if (base_size == 0) {
-		width = gdk_pixbuf_get_width (pixbuf);
-		height = gdk_pixbuf_get_height (pixbuf);
-		size = MAX (width, height);
-		if (size > nominal_size) {
-			base_size = size;
-		}
-		else {
-			/* Don't scale up small icons */
-			base_size = nominal_size;
-		}
-	}
-
-	if (base_size != nominal_size) {
-		scale = (double) nominal_size / base_size;
-		scaled_pixbuf = scale_icon (pixbuf, &scale);
-		g_object_unref (pixbuf);
-		pixbuf = scaled_pixbuf;
-	}
-
-	return pixbuf;
-}
-
-
 static GdkPixbuf *
 get_pixbuf_from_mime_type (const char *mime_type,
 			   int         icon_size)
 {
-	GnomeIconTheme *icon_theme;
-	char           *icon_name = NULL;
-	GdkPixbuf      *icon = NULL;
+	GtkIconTheme *icon_theme;
+	char         *icon_name = NULL;
+	GdkPixbuf    *icon = NULL;
 
-	icon_theme = gnome_icon_theme_new ();
+	icon_theme = gtk_icon_theme_get_default ();
 
 	if (icon_theme == NULL)
 		return NULL;
 
-	gnome_icon_theme_set_allow_svg (icon_theme, TRUE);
-
 	icon_name = gnome_icon_lookup (icon_theme,
 				       NULL,
 				       NULL,
@@ -389,28 +333,14 @@ get_pixbuf_from_mime_type (const char *mime_type,
 				       GNOME_ICON_LOOKUP_FLAGS_NONE,
 				       NULL);
 
-	if (icon_name != NULL) {
-		char                *icon_path = NULL;
-		const GnomeIconData *icon_data;
-		int                  base_size;
-
-		icon_path = gnome_icon_theme_lookup_icon (icon_theme,
-							  icon_name,
-							  icon_size,
-							  &icon_data,
-							  &base_size);
-
-		if (icon_path != NULL) {
-			icon = load_icon_file (icon_path,
-					       base_size, 
-					       icon_size);
-			g_free (icon_path);
-		}
-	}
+	if (icon_name != NULL) 
+		icon = gtk_icon_theme_load_icon (icon_theme,
+						 icon_name,
+						 icon_size,
+						 0,
+						 NULL);
 
 	g_free (icon_name);
-	g_object_unref (icon_theme);
-
 	return icon;
 }
 
@@ -513,12 +443,12 @@ dlg_batch_add_files (FrWindow *window,
 	parent = remove_level_from_path (first_filename);
 
 	if (file_list->next == NULL)
-		automatic_name = g_strdup (file_name_from_path ((char*) file_list->data));
+		automatic_name = gnome_vfs_unescape_string (file_name_from_path ((char*) file_list->data), "");
 	else {
-		automatic_name = g_strdup (file_name_from_path (parent));
+		automatic_name = gnome_vfs_unescape_string (file_name_from_path (parent), "");
 		if ((automatic_name == NULL) || (automatic_name[0] == '\0')) {
 			g_free (automatic_name);
-			automatic_name = g_strdup (file_name_from_path (first_filename));
+			automatic_name = gnome_vfs_unescape_string (file_name_from_path (first_filename), "");
 		}
 	}
 
